# Workbench Themes

<img src="https://github.com/SuperCowPowers/workbench/assets/4806709/4cdd3700-a9d8-441f-a27d-3da1038c7c4d" style="float: right; width: 500px; height: auto; padding: 10px 0px 0px 20px">

The Workbench Dashboard can be customized extensively. Using Workbench **Themes** allows you to customize the User Interfaces to suit your preferences, including completely customized color palettes and fonts. We offer a set of default 'dark' and 'light' themes, but we'll also customize the theme to match your company's color palette and logos.


## Contact Us
Contact us on our [Discord](https://discord.gg/WHAJuz8sw8) channel, we're happy to answer any questions that you might have about **Workbench** and accelerating your AWS ML Pipelines. You can also send us email at [Workbench Info](mailto:workbench@supercowpowers.com) or  [Workbench Sales](mailto:sales@supercowpowers.com).